window.Gleam.initSearch([{"doc":"clip","title":"clip","content":"# clip - A CLI Option Parser for Gleam\n\n[![Package Version](https://img.shields.io/hexpm/v/clip)](https://hex.pm/packages/clip)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/clip/)\n\n`clip` is a library for parsing command line interface options.\n\n## Simple Example\n\n```gleam\nimport argv\nimport clip\nimport clip/opt\nimport gleam/io\nimport gleam/string\n\ntype Person {\n  Person(name: String, age: Int)\n}\n\nfn command() {\n  clip.command({\n    use name &lt;- clip.param\n    use age &lt;- clip.param\n\n    Person(name, age)\n  })\n  |&gt; clip.opt(opt.new(&quot;name&quot;) |&gt; opt.help(&quot;Your name&quot;))\n  |&gt; clip.opt(opt.new(&quot;age&quot;) |&gt; opt.int |&gt; opt.help(&quot;Your age&quot;))\n}\n\npub fn main() {\n  let result =\n    command()\n    |&gt; clip.add_help(&quot;person&quot;, &quot;Create a person&quot;)\n    |&gt; clip.run(argv.load().arguments)\n\n  case result {\n    Error(e) -&gt; io.println_error(e)\n    Ok(person) -&gt; person |&gt; string.inspect |&gt; io.println\n  }\n}\n```\n\n```\n$ gleam run -- --help\n   Compiled in 0.00s\n    Running cli.main\nperson -- Create a person\n\nUsage:\n\n  person [OPTIONS]\n\nOptions:\n\n  (--name NAME) Your name\n  (--age AGE)   Your age\n  [--help,-h]   Print this help\n```\n\n```\n$ gleam run -- --name Drew --age 42\n   Compiled in 0.00s\n    Running cli.main\nPerson(&quot;Drew&quot;, 42)\n```\n\n## Using `clip`\n\n`clip` is an &quot;applicative style&quot; options parser. To use `clip`, follow these\nsteps:\n\n1. First, invoke `clip.command` providing a function to be called with your\n   parsed options. This function can be built using the\n   [param syntax](https://github.com/drewolson/clip/tree/main/examples/param-syntax).\n   Alternatively, you can directly provide a curried function, meaning a two argument\n   function looks like `fn(a) { fn(b) { do_stuff(a, b) } }`.\n2. Next, use the `|&gt;` operator along with `clip.opt`, `clip.flag`, and\n   `clip.arg` to parse command line arguments and provide them as parameters to\n   the function given to `clip.command`.\n3. Optionally use `clip.add_help` to generate help text for your command. The\n   user can view this help text via the `--help,-h` flag.\n4. Finally, run your parser with `clip.run`, giving it the command you have\n   built and the list arguments to parse. I recommend using the `argv` library\n   to access these arguments from both erlang and javascript.\n\n## Types of Options\n\n`clip` provides three types of options:\n\n1. An `Option` is a named option with a value, like `--name &quot;Drew&quot;`. You create\n   `Option`s with the `clip/opt` module and add them to your command with the\n   `clip.opt` function.\n2. A `Flag` is a named option without a value, like `--verbose`. If provided, it\n   produces `True`, if not provided it produces `False`. You create `Flag`s with\n   the `clip/flag` module and add them to your command with the `clip.flag`\n   function.\n3. An `Argument` is a positional value passed to your command. You create\n   `Argument`s with the `clip/arg` module and add them to your command with the\n   `clip.arg`, `clip.arg_many`, and `clip.arg_many1` functions.\n\nTake a look at the\n[examples](https://github.com/drewolson/clip/tree/main/examples) for more information.\n","url":"index.html"},{"doc":"clip/arg","title":"Arg","content":"pub opaque type Arg(a)\n\n\nSynonyms:\nclip/arg.Arg\nclip/arg Arg","url":"clip/arg.html#Arg"},{"doc":"clip/arg","title":"default","content":"pub fn default(arg: Arg(a), default: a) -&gt; Arg(a)\n Provide a default value for an `Arg` when it is not provided by the user.\nSynonyms:\nclip/arg.default\nclip/arg default","url":"clip/arg.html#default"},{"doc":"clip/arg","title":"float","content":"pub fn float(arg: Arg(String)) -&gt; Arg(Float)\n Modify an `Arg(String)` to produce a `Float`.\n\n \n arg.new(&quot;height&quot;)\n |&gt; arg.float\n \n\n Note: `float` changes the type of an `Arg` and therefore clears any\n previously set default value.\nSynonyms:\nclip/arg.float\nclip/arg float","url":"clip/arg.html#float"},{"doc":"clip/arg","title":"help","content":"pub fn help(arg: Arg(a), help: String) -&gt; Arg(a)\n Add help text to an `Arg`.\nSynonyms:\nclip/arg.help\nclip/arg help","url":"clip/arg.html#help"},{"doc":"clip/arg","title":"int","content":"pub fn int(arg: Arg(String)) -&gt; Arg(Int)\n Modify an `Arg(String)` to produce an `Int`.\n\n \n arg.new(&quot;age&quot;)\n |&gt; arg.int\n \n\n Note: `int` changes the type of an `Arg` and therefore clears any\n previously set default value.\nSynonyms:\nclip/arg.int\nclip/arg int","url":"clip/arg.html#int"},{"doc":"clip/arg","title":"map","content":"pub fn map(arg: Arg(a), f: fn(a) -&gt; b) -&gt; Arg(b)\n Modify the value produced by an `Arg` in a way that cannot fail.\n\n \n arg.new(&quot;name&quot;)\n |&gt; arg.map(fn(name) { string.uppercase(name) })\n \n\n Note: `map` can change the type of an `Arg` and therefore clears any\n previously set default value.\nSynonyms:\nclip/arg.map\nclip/arg map","url":"clip/arg.html#map"},{"doc":"clip/arg","title":"new","content":"pub fn new(name: String) -&gt; Arg(String)\n Create a new `Arg` with the provided name. New `Arg`s always initially\n produce a `String`, which is the unmodified value given by the user on the\n command line.\nSynonyms:\nclip/arg.new\nclip/arg new","url":"clip/arg.html#new"},{"doc":"clip/arg","title":"optional","content":"pub fn optional(arg: Arg(a)) -&gt; Arg(Result(a, Nil))\n Transform an `Arg(a)` to an `Arg(Result(a, Nil)`, making it optional.\nSynonyms:\nclip/arg.optional\nclip/arg optional","url":"clip/arg.html#optional"},{"doc":"clip/arg","title":"run","content":"pub fn run(\n  arg: Arg(a),\n  args: List(String),\n) -&gt; Result(#(a, List(String)), String)\n Run an `Arg(a)` against a list of arguments. Used internally by `clip`, not\n intended for direct usage.\nSynonyms:\nclip/arg.run\nclip/arg run","url":"clip/arg.html#run"},{"doc":"clip/arg","title":"run_many","content":"pub fn run_many(\n  arg: Arg(a),\n  args: List(String),\n) -&gt; Result(#(List(a), List(String)), String)\n Run an `Arg(a)` against a list of arguments producing zero or more results.\n Used internally by `clip`, not intended for direct usage.\nSynonyms:\nclip/arg.run_many\nclip/arg run_many","url":"clip/arg.html#run_many"},{"doc":"clip/arg","title":"run_many1","content":"pub fn run_many1(\n  arg: Arg(a),\n  args: List(String),\n) -&gt; Result(#(List(a), List(String)), String)\n Run an `Arg(a)` against a list of arguments producing one or more results.\n Used internally by `clip`, not intended for direct usage.\nSynonyms:\nclip/arg.run_many1\nclip/arg run_many1","url":"clip/arg.html#run_many1"},{"doc":"clip/arg","title":"to_arg_info","content":"pub fn to_arg_info(arg: Arg(a)) -&gt; ArgInfo\n Used internally, not intended for direct usage.\nSynonyms:\nclip/arg.to_arg_info\nclip/arg to_arg_info","url":"clip/arg.html#to_arg_info"},{"doc":"clip/arg","title":"to_arg_info_many","content":"pub fn to_arg_info_many(arg: Arg(a)) -&gt; ArgInfo\n Used internally, not intended for direct usage.\nSynonyms:\nclip/arg.to_arg_info_many\nclip/arg to_arg_info_many","url":"clip/arg.html#to_arg_info_many"},{"doc":"clip/arg","title":"to_arg_info_many1","content":"pub fn to_arg_info_many1(arg: Arg(a)) -&gt; ArgInfo\n Used internally, not intended for direct usage.\nSynonyms:\nclip/arg.to_arg_info_many1\nclip/arg to_arg_info_many1","url":"clip/arg.html#to_arg_info_many1"},{"doc":"clip/arg","title":"try_map","content":"pub fn try_map(\n  arg: Arg(a),\n  f: fn(a) -&gt; Result(b, String),\n) -&gt; Arg(b)\n Modify the value produced by an `Arg` in a way that may fail.\n\n \n arg.new(&quot;age&quot;)\n |&gt; arg.try_map(fn(age_str) {\n   case int.parse(age_str) {\n     Ok(age) -&gt; Ok(age)\n     Error(Nil) -&gt; Error(&quot;Unable to parse integer&quot;)\n   }\n })\n \n\n Note: `try_map` can change the type of an `Arg` and therefore clears any\n previously set default value.\nSynonyms:\nclip/arg.try_map\nclip/arg try_map","url":"clip/arg.html#try_map"},{"doc":"clip/arg","title":"clip/arg","content":" Functions for building `Arg`s. An `Arg` is a positional option.","url":"clip/arg.html"},{"doc":"clip/flag","title":"Flag","content":"pub opaque type Flag\n\n\nSynonyms:\nclip/flag.Flag\nclip/flag Flag","url":"clip/flag.html#Flag"},{"doc":"clip/flag","title":"help","content":"pub fn help(flag: Flag, help: String) -&gt; Flag\n Add help text to a `Flag`.\nSynonyms:\nclip/flag.help\nclip/flag help","url":"clip/flag.html#help"},{"doc":"clip/flag","title":"new","content":"pub fn new(name: String) -&gt; Flag\n Create a new `Flag` with the provided name. `Flag`s always produce a `Bool`\n -- `True` if present and `False` if not present.\nSynonyms:\nclip/flag.new\nclip/flag new","url":"clip/flag.html#new"},{"doc":"clip/flag","title":"run","content":"pub fn run(\n  flag: Flag,\n  args: List(String),\n) -&gt; Result(#(Bool, List(String)), String)\n Run a `Flag` against a list of arguments. Used internally by `clip`, not\n intended for direct usage.\nSynonyms:\nclip/flag.run\nclip/flag run","url":"clip/flag.html#run"},{"doc":"clip/flag","title":"short","content":"pub fn short(flag: Flag, short: String) -&gt; Flag\n Add a short name for the given `Flag`. Short names are provided at the\n command line with a single `-` as a prefix.\n\n \n   clip.command(fn(a) { a })\n   |&gt; clip.flag(flag.new(&quot;debug&quot;) |&gt; flag.short(&quot;d&quot;))\n   |&gt; clip.run([&quot;-d&quot;])\n\n // Ok(True)\n \nSynonyms:\nclip/flag.short\nclip/flag short","url":"clip/flag.html#short"},{"doc":"clip/flag","title":"to_arg_info","content":"pub fn to_arg_info(flag: Flag) -&gt; ArgInfo\n Used internally, not intended for direct usage.\nSynonyms:\nclip/flag.to_arg_info\nclip/flag to_arg_info","url":"clip/flag.html#to_arg_info"},{"doc":"clip/flag","title":"clip/flag","content":" Functions for building `Flag`s. A `Flag` is a named option with no\n associated value, such as `--debug`. A `Flag` produces `True` when present\n and `False` when not present.","url":"clip/flag.html"},{"doc":"clip/opt","title":"Opt","content":"pub opaque type Opt(a)\n\n\nSynonyms:\nclip/opt.Opt\nclip/opt Opt","url":"clip/opt.html#Opt"},{"doc":"clip/opt","title":"default","content":"pub fn default(opt: Opt(a), default: a) -&gt; Opt(a)\n Provide a default value for an `Opt` when it is not provided by the user.\nSynonyms:\nclip/opt.default\nclip/opt default","url":"clip/opt.html#default"},{"doc":"clip/opt","title":"float","content":"pub fn float(opt: Opt(String)) -&gt; Opt(Float)\n Modify an `Opt(String)` to produce a `Float`.\n\n \n opt.new(&quot;height&quot;)\n |&gt; opt.float\n \n\n Note: `float` changes the type of an `Opt` and therefore clears any\n previously set default value.\nSynonyms:\nclip/opt.float\nclip/opt float","url":"clip/opt.html#float"},{"doc":"clip/opt","title":"help","content":"pub fn help(opt: Opt(a), help: String) -&gt; Opt(a)\n Add help text to an `Opt`.\nSynonyms:\nclip/opt.help\nclip/opt help","url":"clip/opt.html#help"},{"doc":"clip/opt","title":"int","content":"pub fn int(opt: Opt(String)) -&gt; Opt(Int)\n Modify an `Opt(String)` to produce an `Int`.\n\n \n opt.new(&quot;age&quot;)\n |&gt; opt.int\n \n\n Note: `int` changes the type of an `Opt` and therefore clears any\n previously set default value.\nSynonyms:\nclip/opt.int\nclip/opt int","url":"clip/opt.html#int"},{"doc":"clip/opt","title":"map","content":"pub fn map(opt: Opt(a), f: fn(a) -&gt; b) -&gt; Opt(b)\n Modify the value produced by an `Opt` in a way that cannot fail.\n\n \n opt.new(&quot;name&quot;)\n |&gt; opt.map(fn(name) { string.uppercase(name) })\n \n\n Note: `map` can change the type of an `Opt` and therefore clears any\n previously set default value.\nSynonyms:\nclip/opt.map\nclip/opt map","url":"clip/opt.html#map"},{"doc":"clip/opt","title":"new","content":"pub fn new(name: String) -&gt; Opt(String)\n Create a new `Opt` with the provided name. New `Opt`s always initially\n produce a `String`, which is the unmodified value given by the user on the\n command line.\nSynonyms:\nclip/opt.new\nclip/opt new","url":"clip/opt.html#new"},{"doc":"clip/opt","title":"optional","content":"pub fn optional(opt: Opt(a)) -&gt; Opt(Result(a, Nil))\n Transform an `Opt(a)` to an `Opt(Result(a, Nil)`, making it optional.\nSynonyms:\nclip/opt.optional\nclip/opt optional","url":"clip/opt.html#optional"},{"doc":"clip/opt","title":"run","content":"pub fn run(\n  opt: Opt(a),\n  args: List(String),\n) -&gt; Result(#(a, List(String)), String)\n Run an `Opt(a)` against a list of arguments. Used internally by `clip`, not\n intended for direct usage.\nSynonyms:\nclip/opt.run\nclip/opt run","url":"clip/opt.html#run"},{"doc":"clip/opt","title":"short","content":"pub fn short(opt: Opt(String), short_name: String) -&gt; Opt(String)\n Add a short name for the given `Opt`. Short names are provided at the\n command line with a single `-` as a prefix.\n\n \n   clip.command(fn(a) { a })\n   |&gt; clip.opt(opt.new(&quot;name&quot;) |&gt; opt.short(&quot;n&quot;))\n   |&gt; clip.run([&quot;-n&quot;, &quot;Drew&quot;])\n\n // Ok(&quot;Drew&quot;)\n \nSynonyms:\nclip/opt.short\nclip/opt short","url":"clip/opt.html#short"},{"doc":"clip/opt","title":"to_arg_info","content":"pub fn to_arg_info(opt: Opt(a)) -&gt; ArgInfo\n Used internally, not intended for direct usage.\nSynonyms:\nclip/opt.to_arg_info\nclip/opt to_arg_info","url":"clip/opt.html#to_arg_info"},{"doc":"clip/opt","title":"try_map","content":"pub fn try_map(\n  opt: Opt(a),\n  f: fn(a) -&gt; Result(b, String),\n) -&gt; Opt(b)\n Modify the value produced by an `Opt` in a way that may fail.\n\n \n opt.new(&quot;age&quot;)\n |&gt; opt.try_map(fn(age_str) {\n   case int.parse(age_str) {\n     Ok(age) -&gt; Ok(age)\n     Error(Nil) -&gt; Error(&quot;Unable to parse integer&quot;)\n   }\n })\n \n\n Note: `try_map` can change the type of an `Opt` and therefore clears any\n previously set default value.\nSynonyms:\nclip/opt.try_map\nclip/opt try_map","url":"clip/opt.html#try_map"},{"doc":"clip/opt","title":"clip/opt","content":" Functions for building `Opt`s. An `Opt` is a named option with a\n value, such as `--name &quot;Drew&quot;`","url":"clip/opt.html"},{"doc":"clip","title":"Command","content":"pub opaque type Command(a)\n\n\nSynonyms:\nclip.Command\nclip Command","url":"clip.html#Command"},{"doc":"clip","title":"add_help","content":"pub fn add_help(\n  command: Command(a),\n  name: String,\n  description: String,\n) -&gt; Command(a)\n Add the help (`-h`, `--help`) flags to your program to display usage help\n to the user. The provided `name` and `description` will be used to generate\n the help text.\nSynonyms:\nclip.add_help\nclip add_help","url":"clip.html#add_help"},{"doc":"clip","title":"apply","content":"pub fn apply(\n  mf: Command(fn(a) -&gt; b),\n  ma: Command(a),\n) -&gt; Command(b)\n Don&#39;t call this function directly. Rather, call `cli.opt`, `clip.flag`,\n `clip.arg`, `clip.arg_many`, or `clip.arg_many1`.\nSynonyms:\nclip.apply\nclip apply","url":"clip.html#apply"},{"doc":"clip","title":"arg","content":"pub fn arg(\n  command: Command(fn(a) -&gt; b),\n  arg: Arg(a),\n) -&gt; Command(b)\n Parse the next positional argument built using the `clip/arg` module and\n provide it to a `Command` function build using `clip.command()`\n\n \n clip.command(fn(a) { a })\n |&gt; clip.arg(arg.new(&quot;foo&quot;))\n |&gt; clip.run([&quot;foo&quot;])\n\n // Ok(&quot;foo&quot;)\n \n\n `arg` will not attempt to parse options starting with `-` unless the\n special `--` value has been previously passed or the option is a negative\n integer or float.\nSynonyms:\nclip.arg\nclip arg","url":"clip.html#arg"},{"doc":"clip","title":"arg_many","content":"pub fn arg_many(\n  command: Command(fn(List(a)) -&gt; b),\n  arg: Arg(a),\n) -&gt; Command(b)\n Parse the next zero or more positional arguments built using the `clip/arg`\n module and provide them as a `List` to a `Command` function build using\n `clip.command()`. `arg_many` is greedy, parsing as many options as possible\n until parsing fails. If zero values are parsed successfuly, an empty\n `List` is provided.\n\n \n clip.command(fn(a) { a })\n |&gt; clip.arg_many(arg.new(&quot;foo&quot;))\n |&gt; clip.run([&quot;foo&quot;, &quot;bar&quot;, &quot;baz&quot;])\n\n // Ok([&quot;foo&quot;, &quot;bar&quot;, &quot;baz&quot;])\n \n\n `arg_many` will not attempt to parse options starting with `-` unless the\n special `--` value has been previously passed or the option is a negative\n integer or float.\nSynonyms:\nclip.arg_many\nclip arg_many","url":"clip.html#arg_many"},{"doc":"clip","title":"arg_many1","content":"pub fn arg_many1(\n  command: Command(fn(List(a)) -&gt; b),\n  arg: Arg(a),\n) -&gt; Command(b)\n Parse the next one or more positional arguments built using the `clip/arg`\n module and provide them as a `List` to a `Command` function build using\n `clip.command()`. `arg_many` is greedy, parsing as many options as possible\n until parsing fails. Parsing fails if zero values are parsed successfully.\n\n \n clip.command(fn(a) { a })\n |&gt; clip.arg_many1(arg.new(&quot;foo&quot;))\n |&gt; clip.run([&quot;foo&quot;, &quot;bar&quot;, &quot;baz&quot;])\n\n // Ok([&quot;foo&quot;, &quot;bar&quot;, &quot;baz&quot;])\n \n\n `arg_many1` will not attempt to parse options starting with `-` unless the\n special `--` value has been previously passed or the option is a negative\n integer or float.\nSynonyms:\nclip.arg_many1\nclip arg_many1","url":"clip.html#arg_many1"},{"doc":"clip","title":"command","content":"pub fn command(f: fn(a) -&gt; b) -&gt; Command(fn(a) -&gt; b)\n The `command` function is use to start building a parser. You provide a\n curried function and then provide arguments to be supplied to that function.\n\n \n clip.command(fn(a) { fn(b) { #(a, b) } })\n |&gt; clip.opt(opt.new(&quot;first&quot;))\n |&gt; clip.opt(opt.new(&quot;second&quot;))\n |&gt; clip.run([&quot;--first&quot;, &quot;foo&quot;, &quot;--second&quot;, &quot;bar&quot;])\n\n // Ok(#(&quot;foo&quot;, &quot;bar&quot;))\n \nSynonyms:\nclip.command\nclip command","url":"clip.html#command"},{"doc":"clip","title":"fail","content":"pub fn fail(message: String) -&gt; Command(a)\n Creates a `Command` that always produces `Error(message)` when run.\nSynonyms:\nclip.fail\nclip fail","url":"clip.html#fail"},{"doc":"clip","title":"flag","content":"pub fn flag(\n  command: Command(fn(Bool) -&gt; a),\n  flag: Flag,\n) -&gt; Command(a)\n Parse a flag built using the `clip/flag` module and provide it to a\n `Command` function build using `clip.command()`\n\n \n clip.command(fn(a) { a })\n |&gt; clip.flag(flag.new(&quot;foo&quot;))\n |&gt; clip.run([&quot;--foo&quot;])\n\n // Ok(True)\n \nSynonyms:\nclip.flag\nclip flag","url":"clip.html#flag"},{"doc":"clip","title":"opt","content":"pub fn opt(\n  command: Command(fn(a) -&gt; b),\n  opt: Opt(a),\n) -&gt; Command(b)\n Parse an option built using the `clip/opt` module and provide it to a\n `Command` function build using `clip.command()`\n\n \n clip.command(fn(a) { a })\n |&gt; clip.opt(opt.new(&quot;first&quot;))\n |&gt; clip.run([&quot;--first&quot;, &quot;foo&quot;])\n\n // Ok(&quot;foo&quot;)\n \nSynonyms:\nclip.opt\nclip opt","url":"clip.html#opt"},{"doc":"clip","title":"param","content":"pub fn param(f: fn(a) -&gt; b) -&gt; fn(a) -&gt; b\n The `param` function provides an alternative syntax for building curried\n functions. The following two code blocks are equivalent:\n\n \n fn(a) {\n   fn(b) {\n     thing(a, b)\n   }\n }\n \n\n \n {\n   use a &lt;- clip.param\n   use b &lt;- clip.param\n\n   thing(a, b)\n }\n \n\n You can use either style when calling `clip.command`.\n See the [param syntax example](https://github.com/drewolson/clip/tree/main/examples/param-syntax)\n for more details.\nSynonyms:\nclip.param\nclip param","url":"clip.html#param"},{"doc":"clip","title":"return","content":"pub fn return(val: a) -&gt; Command(a)\n The `return` function takes a value `val` and produces a `Command` that, when\n run, produces `val`. You should only call this function directly when your\n command doesn&#39;t require any arguments. Otherwise, use `clip.command`.\n\n \n  clip.return(1) |&gt; clip.run([&quot;whatever&quot;])\n\n  // Ok(1)\n \n\n See the [subcommand example](https://github.com/drewolson/clip/tree/main/examples/subcommand)\n for idiomatic usage of `return`.\nSynonyms:\nclip.return\nclip return","url":"clip.html#return"},{"doc":"clip","title":"run","content":"pub fn run(\n  command: Command(a),\n  args: List(String),\n) -&gt; Result(a, String)\n Run a command. Running a `Command(a)` will return either `Ok(a)` or an\n `Error(String)`. The `Error` value is intended to be printed to the user.\nSynonyms:\nclip.run\nclip run","url":"clip.html#run"},{"doc":"clip","title":"subcommands","content":"pub fn subcommands(\n  subcommands: List(#(String, Command(a))),\n) -&gt; Command(a)\n Build a command with subcommands. This is an advanced use case, see the\n examples directory for more help.\nSynonyms:\nclip.subcommands\nclip subcommands","url":"clip.html#subcommands"},{"doc":"clip","title":"subcommands_with_default","content":"pub fn subcommands_with_default(\n  subcommands: List(#(String, Command(a))),\n  default: Command(a),\n) -&gt; Command(a)\n Build a command with subcommands and a default top-level command if no\n subcommand matches. This is an advanced use case, see the examples directory\n for more help.\nSynonyms:\nclip.subcommands_with_default\nclip subcommands_with_default","url":"clip.html#subcommands_with_default"},{"doc":"clip","title":"clip","content":" Functions for building `Command`s.","url":"clip.html"}]);